/*
 * Execute tables below to create AOE tables used for CONNECT demo environment.
 * AOE database must first be created.
 */

CREATE TYPE AccountNumber FROM nvarchar(15) NULL
go

CREATE TYPE Flag FROM bit NOT NULL
go

CREATE TYPE Name FROM nvarchar(50) NULL
go

CREATE TYPE NameStyle FROM bit NOT NULL
go

CREATE TYPE OrderNumber FROM nvarchar(25) NULL
go

CREATE TYPE Phone FROM nvarchar(25) NULL
go

/* 
 * TABLE: Adr 
 */

CREATE TABLE Adr(
    AdrID        int                 IDENTITY(1,1) NOT FOR REPLICATION,
    AdrLine1     nvarchar(60)        NOT NULL,
    AdrLine2     nvarchar(60)        NULL,
    City         varchar(40)         NOT NULL,
    StePovID     int                 NOT NULL,
    PslCde       nvarchar(15)        NOT NULL,
    rowguid      uniqueidentifier    ROWGUIDCOL NOT NULL,
    MdfDte       datetime            NOT NULL,
    newcolumn    datetime            NULL,
    CONSTRAINT PK_Address_AddressID PRIMARY KEY CLUSTERED (AdrID)
)
go



IF OBJECT_ID('Adr') IS NOT NULL
    PRINT '<<< CREATED TABLE Adr >>>'
ELSE
    PRINT '<<< FAILED CREATING TABLE Adr >>>'
go

/* 
 * TABLE: AdrTyp 
 */

CREATE TABLE AdrTyp(
    AdrTypID    int                 IDENTITY(1,1),
    Nme         Name                NOT NULL,
    rowguid     uniqueidentifier    ROWGUIDCOL NOT NULL,
    MdfDte      datetime            NOT NULL,
    CONSTRAINT PK_AddressType_AddressTypeID PRIMARY KEY CLUSTERED (AdrTypID)
)
go



IF OBJECT_ID('AdrTyp') IS NOT NULL
    PRINT '<<< CREATED TABLE AdrTyp >>>'
ELSE
    PRINT '<<< FAILED CREATING TABLE AdrTyp >>>'
go

/* 
 * TABLE: AWBuildVrn 
 */

CREATE TABLE AWBuildVrn(
    SysInfID        tinyint         IDENTITY(1,1),
    [Database Vrn]  nvarchar(25)    NOT NULL,
    VrnDte          datetime        NOT NULL,
    MdfDte          datetime        NOT NULL,
    CONSTRAINT PK_AWBuildVersion_SystemInformationID PRIMARY KEY CLUSTERED (SysInfID)
)
go



IF OBJECT_ID('AWBuildVrn') IS NOT NULL
    PRINT '<<< CREATED TABLE AWBuildVrn >>>'
ELSE
    PRINT '<<< FAILED CREATING TABLE AWBuildVrn >>>'
go

/* 
 * TABLE: BllOfMls 
 */

CREATE TABLE BllOfMls(
    BllOfMlsID    int              IDENTITY(1,1),
    PdtID         int              NULL,
    PdtID_1       int              NOT NULL,
    SttDte        datetime         NOT NULL,
    EndDte        datetime         NULL,
    UitMsrCde     nchar(3)         NOT NULL,
    BOMLevel      smallint         NOT NULL,
    PerAsmQty     decimal(8, 2)    NOT NULL,
    MdfDte        datetime         NOT NULL,
    CONSTRAINT PK_BillOfMaterials_BillOfMaterialsID PRIMARY KEY NONCLUSTERED (BllOfMlsID)
)
go



IF OBJECT_ID('BllOfMls') IS NOT NULL
    PRINT '<<< CREATED TABLE BllOfMls >>>'
ELSE
    PRINT '<<< FAILED CREATING TABLE BllOfMls >>>'
go

/* 
 * TABLE: Cct 
 */

CREATE TABLE Cct(
    CctID         int                 IDENTITY(1,1) NOT FOR REPLICATION,
    NmeStl        NameStyle           NOT NULL,
    Title         nvarchar(9)         NULL,
    FrsNme        Name                NOT NULL,
    MdlNme        Name                NULL,
    LstNme        Name                NOT NULL,
    Sfx           nvarchar(10)        NULL,
    EmlAdr        nvarchar(50)        NULL,
    EmlPrm        int                 NOT NULL,
    Phone         Phone               NULL,
    PssHsh        varchar(40)         NOT NULL,
    PssSalt       varchar(10)         NOT NULL,
    AdlCctInfo    int                 NULL,
    rowguid       uniqueidentifier    ROWGUIDCOL NOT NULL,
    MdfDte        datetime            NOT NULL,
    CONSTRAINT PK_Contact_ContactID PRIMARY KEY CLUSTERED (CctID)
)
go



IF OBJECT_ID('Cct') IS NOT NULL
    PRINT '<<< CREATED TABLE Cct >>>'
ELSE
    PRINT '<<< FAILED CREATING TABLE Cct >>>'
go

/* 
 * TABLE: CctCrtCrd 
 */

CREATE TABLE CctCrtCrd(
    CctID       int         NOT NULL,
    CrtCrdID    int         NOT NULL,
    MdfDte      datetime    NOT NULL,
    CONSTRAINT PK_ContactCartCard_ContactID_CartCardID PRIMARY KEY CLUSTERED (CctID, CrtCrdID)
)
go



IF OBJECT_ID('CctCrtCrd') IS NOT NULL
    PRINT '<<< CREATED TABLE CctCrtCrd >>>'
ELSE
    PRINT '<<< FAILED CREATING TABLE CctCrtCrd >>>'
go

/* 
 * TABLE: CctTyp 
 */

CREATE TABLE CctTyp(
    CctTypID    int         IDENTITY(1,1),
    Nme         Name        NOT NULL,
    MdfDte      datetime    NOT NULL,
    CONSTRAINT PK_ContactType_ContactTypeID PRIMARY KEY CLUSTERED (CctTypID)
)
go



IF OBJECT_ID('CctTyp') IS NOT NULL
    PRINT '<<< CREATED TABLE CctTyp >>>'
ELSE
    PRINT '<<< FAILED CREATING TABLE CctTyp >>>'
go

/* 
 * TABLE: Cmr 
 */

CREATE TABLE Cmr(
    CmrID      int                 IDENTITY(1,1) NOT FOR REPLICATION,
    TtyID      int                 NULL,
    ActNmb     int                 NULL,
    CmrTyp     nchar(1)            NOT NULL,
    rowguid    uniqueidentifier    ROWGUIDCOL NOT NULL,
    MdfDte     datetime            NOT NULL,
    CONSTRAINT PK_Customer_CustomerID PRIMARY KEY CLUSTERED (CmrID)
)
go



IF OBJECT_ID('Cmr') IS NOT NULL
    PRINT '<<< CREATED TABLE Cmr >>>'
ELSE
    PRINT '<<< FAILED CREATING TABLE Cmr >>>'
go

/* 
 * TABLE: CmrAdr 
 */

CREATE TABLE CmrAdr(
    CmrID       int                 NOT NULL,
    AdrID       int                 NOT NULL,
    AdrTypID    int                 NOT NULL,
    rowguid     uniqueidentifier    ROWGUIDCOL NOT NULL,
    MdfDte      datetime            NOT NULL,
    CONSTRAINT PK_CustomerAddress_CustomerID_AddressID PRIMARY KEY CLUSTERED (CmrID, AdrID)
)
go



IF OBJECT_ID('CmrAdr') IS NOT NULL
    PRINT '<<< CREATED TABLE CmrAdr >>>'
ELSE
    PRINT '<<< FAILED CREATING TABLE CmrAdr >>>'
go

/* 
 * TABLE: CrtCrd 
 */

CREATE TABLE CrtCrd(
    CrtCrdID    int             IDENTITY(1,1),
    CrdTyp      nvarchar(50)    NOT NULL,
    CrdNmb      nvarchar(25)    NOT NULL,
    ExpMonth    tinyint         NOT NULL,
    ExpYear     smallint        NOT NULL,
    MdfDte      datetime        NOT NULL,
    CONSTRAINT PK_CartCard_CartCardID PRIMARY KEY CLUSTERED (CrtCrdID)
)
go



IF OBJECT_ID('CrtCrd') IS NOT NULL
    PRINT '<<< CREATED TABLE CrtCrd >>>'
ELSE
    PRINT '<<< FAILED CREATING TABLE CrtCrd >>>'
go

/* 
 * TABLE: Cry 
 */

CREATE TABLE Cry(
    CryCde    nchar(3)    NOT NULL,
    Nme       Name        NOT NULL,
    MdfDte    datetime    NOT NULL,
    CONSTRAINT PK_Currency_CurrencyCode PRIMARY KEY CLUSTERED (CryCde)
)
go



IF OBJECT_ID('Cry') IS NOT NULL
    PRINT '<<< CREATED TABLE Cry >>>'
ELSE
    PRINT '<<< FAILED CREATING TABLE Cry >>>'
go

/* 
 * TABLE: CryRat 
 */

CREATE TABLE CryRat(
    CryRatID       int         IDENTITY(1,1),
    CryRatDte      datetime    NOT NULL,
    CryCde         nchar(3)    NOT NULL,
    CryCde_1       nchar(3)    NOT NULL,
    AverageRat     money       NOT NULL,
    EndOfDayRat    money       NOT NULL,
    MdfDte         datetime    NOT NULL,
    CONSTRAINT PK_CurrencyRate_CurrencyRateID PRIMARY KEY CLUSTERED (CryRatID)
)
go



IF OBJECT_ID('CryRat') IS NOT NULL
    PRINT '<<< CREATED TABLE CryRat >>>'
ELSE
    PRINT '<<< FAILED CREATING TABLE CryRat >>>'
go

/* 
 * TABLE: Ctr 
 */

CREATE TABLE Ctr(
    CtrID                  nchar(6)       NOT NULL,
    Nme                    Name           NOT NULL,
    MdfDte                 datetime       NOT NULL,
    New_Customer_Column    varchar(23)    NULL,
    CONSTRAINT PK_Culture_CultureID PRIMARY KEY CLUSTERED (CtrID)
)
go



IF OBJECT_ID('Ctr') IS NOT NULL
    PRINT '<<< CREATED TABLE Ctr >>>'
ELSE
    PRINT '<<< FAILED CREATING TABLE Ctr >>>'
go

/* 
 * TABLE: CtyRgn 
 */

CREATE TABLE CtyRgn(
    CtyRgnCde    nvarchar(3)    NOT NULL,
    Nme          Name           NOT NULL,
    MdfDte       datetime       NOT NULL,
    CONSTRAINT PK_CategoryRegion_CategoryRegionCode PRIMARY KEY CLUSTERED (CtyRgnCde)
)
go



IF OBJECT_ID('CtyRgn') IS NOT NULL
    PRINT '<<< CREATED TABLE CtyRgn >>>'
ELSE
    PRINT '<<< FAILED CREATING TABLE CtyRgn >>>'
go

/* 
 * TABLE: CtyRgnCry 
 */

CREATE TABLE CtyRgnCry(
    CtyRgnCde    nvarchar(3)    NOT NULL,
    CryCde       nchar(3)       NOT NULL,
    MdfDte       datetime       NOT NULL,
    CONSTRAINT PK_CategoryRegionCurrency_CategoryRegionCode_CurrencyCode PRIMARY KEY CLUSTERED (CtyRgnCde, CryCde)
)
go



IF OBJECT_ID('CtyRgnCry') IS NOT NULL
    PRINT '<<< CREATED TABLE CtyRgnCry >>>'
ELSE
    PRINT '<<< FAILED CREATING TABLE CtyRgnCry >>>'
go

/* 
 * TABLE: Dct 
 */

CREATE TABLE Dct(
    DctID       int               IDENTITY(1,1),
    Title       nvarchar(50)      NOT NULL,
    FileNme     nvarchar(400)     NOT NULL,
    FileExt     nvarchar(8)       NOT NULL,
    Revision    nchar(5)          NOT NULL,
    ChgNmb      int               NOT NULL,
    Status      tinyint           NOT NULL,
    DctSmy      nvarchar(max)     NULL,
    Dct         varbinary(max)    NULL,
    MdfDte      datetime          NOT NULL,
    CONSTRAINT PK_Document_DocumentID PRIMARY KEY CLUSTERED (DctID)
)
go



IF OBJECT_ID('Dct') IS NOT NULL
    PRINT '<<< CREATED TABLE Dct >>>'
ELSE
    PRINT '<<< FAILED CREATING TABLE Dct >>>'
go

/* 
 * TABLE: Dep 
 */

CREATE TABLE Dep(
    DepID     smallint    IDENTITY(1,1),
    Nme       Name        NOT NULL,
    GrpNme    Name        NOT NULL,
    MdfDte    datetime    NOT NULL,
    CONSTRAINT PK_Department_DepartmentID PRIMARY KEY CLUSTERED (DepID)
)
go



IF OBJECT_ID('Dep') IS NOT NULL
    PRINT '<<< CREATED TABLE Dep >>>'
ELSE
    PRINT '<<< FAILED CREATING TABLE Dep >>>'
go

/* 
 * TABLE: Emp 
 */

CREATE TABLE Emp(
    EmpID                   int                 IDENTITY(1,1),
    NatIDNumber             nvarchar(15)        NOT NULL,
    CctID                   int                 NOT NULL,
    LoginID                 nvarchar(256)       NOT NULL,
    EmpID_1                 int                 NULL,
    Title                   nvarchar(50)        NOT NULL,
    BirthDte                datetime            NOT NULL,
    MrtStatus               nchar(1)            NOT NULL,
    Gender                  nchar(1)            NOT NULL,
    HireDte                 datetime            NOT NULL,
    SalariedFlag            Flag                NOT NULL,
    VctHrs                  smallint            NOT NULL,
    SckLveHrs               smallint            NOT NULL,
    CrtFlag                 Flag                NOT NULL,
    rowguid                 uniqueidentifier    ROWGUIDCOL NOT NULL,
    MdfDte                  datetime            NOT NULL,
    EncryptedNatIDNumber    varbinary(128)      NULL,
    CONSTRAINT PK_Employee_EmployeeID PRIMARY KEY CLUSTERED (EmpID)
)
go



IF OBJECT_ID('Emp') IS NOT NULL
    PRINT '<<< CREATED TABLE Emp >>>'
ELSE
    PRINT '<<< FAILED CREATING TABLE Emp >>>'
go

/* 
 * TABLE: EmpAdr 
 */

CREATE TABLE EmpAdr(
    EmpID      int                 NOT NULL,
    AdrID      int                 NOT NULL,
    rowguid    uniqueidentifier    ROWGUIDCOL NOT NULL,
    MdfDte     datetime            NOT NULL,
    CONSTRAINT PK_EmployeeAddress_EmployeeID_AddressID PRIMARY KEY CLUSTERED (EmpID, AdrID)
)
go



IF OBJECT_ID('EmpAdr') IS NOT NULL
    PRINT '<<< CREATED TABLE EmpAdr >>>'
ELSE
    PRINT '<<< FAILED CREATING TABLE EmpAdr >>>'
go

/* 
 * TABLE: EmpDepHst 
 */

CREATE TABLE EmpDepHst(
    EmpID     int         NOT NULL,
    DepID     smallint    NOT NULL,
    SftID     tinyint     NOT NULL,
    SttDte    datetime    NOT NULL,
    EndDte    datetime    NULL,
    MdfDte    datetime    NOT NULL,
    CONSTRAINT PK_EmployeeDepartmentHistory_EmployeeID_StartDate_DepartmentID PRIMARY KEY CLUSTERED (EmpID, SttDte, DepID, SftID)
)
go



IF OBJECT_ID('EmpDepHst') IS NOT NULL
    PRINT '<<< CREATED TABLE EmpDepHst >>>'
ELSE
    PRINT '<<< FAILED CREATING TABLE EmpDepHst >>>'
go

/* 
 * TABLE: EmpPayHst 
 */

CREATE TABLE EmpPayHst(
    EmpID           int         NOT NULL,
    RatChgDte       datetime    NOT NULL,
    Rat             money       NOT NULL,
    PayFrequency    tinyint     NOT NULL,
    MdfDte          datetime    NOT NULL,
    CONSTRAINT PK_EmployeePayHistory_EmployeeID_RateChangeDate PRIMARY KEY CLUSTERED (EmpID, RatChgDte)
)
go



IF OBJECT_ID('EmpPayHst') IS NOT NULL
    PRINT '<<< CREATED TABLE EmpPayHst >>>'
ELSE
    PRINT '<<< FAILED CREATING TABLE EmpPayHst >>>'
go

/* 
 * TABLE: ErrLog 
 */

CREATE TABLE ErrLog(
    ErrLogID        int               IDENTITY(1,1),
    ErrTime         datetime          NOT NULL,
    UserNme         char(10)          NOT NULL,
    ErrNmb          int               NOT NULL,
    ErrSev          int               NULL,
    ErrSte          int               NULL,
    ErrProcedure    nvarchar(126)     NULL,
    ErrLine         int               NULL,
    ErrMessage      nvarchar(4000)    NOT NULL,
    CONSTRAINT PK_ErrorLog_ErrorLogID PRIMARY KEY CLUSTERED (ErrLogID)
)
go



IF OBJECT_ID('ErrLog') IS NOT NULL
    PRINT '<<< CREATED TABLE ErrLog >>>'
ELSE
    PRINT '<<< FAILED CREATING TABLE ErrLog >>>'
go

/* 
 * TABLE: Ill 
 */

CREATE TABLE Ill(
    IllID      int         IDENTITY(1,1),
    Diagram    xml         NULL,
    MdfDte     datetime    NOT NULL,
    CONSTRAINT PK_Illustration_IllustrationID PRIMARY KEY CLUSTERED (IllID)
)
go



IF OBJECT_ID('Ill') IS NOT NULL
    PRINT '<<< CREATED TABLE Ill >>>'
ELSE
    PRINT '<<< FAILED CREATING TABLE Ill >>>'
go

/* 
 * TABLE: Loc 
 */

CREATE TABLE Loc(
    LocID           smallint         IDENTITY(1,1),
    Nme             Name             NOT NULL,
    CstRat          smallmoney       NOT NULL,
    Availability    decimal(8, 2)    NOT NULL,
    MdfDte          datetime         NOT NULL,
    CONSTRAINT PK_Location_LocationID PRIMARY KEY CLUSTERED (LocID)
)
go



IF OBJECT_ID('Loc') IS NOT NULL
    PRINT '<<< CREATED TABLE Loc >>>'
ELSE
    PRINT '<<< FAILED CREATING TABLE Loc >>>'
go

/* 
 * TABLE: Pdt 
 */

CREATE TABLE Pdt(
    PdtID          int                 IDENTITY(1,1),
    Nme            Name                NOT NULL,
    PdtNmb         nvarchar(25)        NOT NULL,
    MakeFlag       Flag                NOT NULL,
    FsdGdsFlag     Flag                NOT NULL,
    Color          nvarchar(15)        NULL,
    SftStkLvl      smallint            NOT NULL,
    RdrPnt         smallint            NOT NULL,
    StdCst         money               NOT NULL,
    LstPrc         money               NOT NULL,
    Sze            nvarchar(5)         NULL,
    UitMsrCde      nchar(3)            NULL,
    UitMsrCde_1    nchar(3)            NULL,
    Weight         decimal(8, 2)       NULL,
    DaysToMft      int                 NOT NULL,
    PdtLine        nchar(2)            NULL,
    Class          nchar(2)            NULL,
    Stl            nchar(2)            NULL,
    PdtScyID       int                 NULL,
    PdtModelID     int                 NULL,
    SellSttDte     datetime            NOT NULL,
    SellEndDte     datetime            NULL,
    DscDte         datetime            NULL,
    rowguid        uniqueidentifier    ROWGUIDCOL NOT NULL,
    MdfDte         datetime            NOT NULL,
    CONSTRAINT PK_Product_ProductID PRIMARY KEY CLUSTERED (PdtID)
)
go



IF OBJECT_ID('Pdt') IS NOT NULL
    PRINT '<<< CREATED TABLE Pdt >>>'
ELSE
    PRINT '<<< FAILED CREATING TABLE Pdt >>>'
go

/* 
 * TABLE: Pdt_02182013171245000 
 */

CREATE TABLE Pdt_02182013171245000(
    PdtID          int                 IDENTITY(1,1),
    Nme            Name                NOT NULL,
    PdtNmb         nvarchar(25)        NOT NULL,
    MakeFlag       Flag                NOT NULL,
    FsdGdsFlag     Flag                NOT NULL,
    Color          nvarchar(15)        NULL,
    SftStkLvl      smallint            NOT NULL,
    RdrPnt         smallint            NOT NULL,
    StdCst         money               NOT NULL,
    LstPrc         money               NOT NULL,
    Sze            nvarchar(5)         NULL,
    UitMsrCde      nchar(3)            NULL,
    UitMsrCde_1    nchar(3)            NULL,
    Weight         decimal(8, 2)       NULL,
    DaysToMft      int                 NOT NULL,
    PdtLine        nchar(2)            NULL,
    Class          nchar(2)            NULL,
    Stl            nchar(2)            NULL,
    PdtScyID       int                 NULL,
    PdtModelID     int                 NULL,
    SellSttDte     datetime            NOT NULL,
    SellEndDte     datetime            NULL,
    DscDte         datetime            NULL,
    rowguid        uniqueidentifier    ROWGUIDCOL NOT NULL,
    MdfDte         datetime            NOT NULL,
    CONSTRAINT PK_Product_02182013171245001 PRIMARY KEY CLUSTERED (PdtID)
)
go



IF OBJECT_ID('Pdt_02182013171245000') IS NOT NULL
    PRINT '<<< CREATED TABLE Pdt_02182013171245000 >>>'
ELSE
    PRINT '<<< FAILED CREATING TABLE Pdt_02182013171245000 >>>'
go

/* 
 * TABLE: PdtCstHst 
 */

CREATE TABLE PdtCstHst(
    PdtID     int         NOT NULL,
    SttDte    datetime    NOT NULL,
    EndDte    datetime    NULL,
    StdCst    money       NOT NULL,
    MdfDte    datetime    NOT NULL,
    CONSTRAINT PK_ProductCostHistory_ProductID_StartDate PRIMARY KEY CLUSTERED (PdtID, SttDte)
)
go



IF OBJECT_ID('PdtCstHst') IS NOT NULL
    PRINT '<<< CREATED TABLE PdtCstHst >>>'
ELSE
    PRINT '<<< FAILED CREATING TABLE PdtCstHst >>>'
go

/* 
 * TABLE: PdtCty 
 */

CREATE TABLE PdtCty(
    PdtCtyID    int                 IDENTITY(1,1),
    Nme         Name                NOT NULL,
    rowguid     uniqueidentifier    ROWGUIDCOL NOT NULL,
    MdfDte      datetime            NOT NULL,
    CONSTRAINT PK_ProductCategory_ProductCategoryID PRIMARY KEY CLUSTERED (PdtCtyID)
)
go



IF OBJECT_ID('PdtCty') IS NOT NULL
    PRINT '<<< CREATED TABLE PdtCty >>>'
ELSE
    PRINT '<<< FAILED CREATING TABLE PdtCty >>>'
go

/* 
 * TABLE: PdtDct 
 */

CREATE TABLE PdtDct(
    PdtID     int         NOT NULL,
    DctID     int         NOT NULL,
    MdfDte    datetime    NOT NULL,
    CONSTRAINT PK_ProductDocument_ProductID_DocumentID PRIMARY KEY CLUSTERED (PdtID, DctID)
)
go



IF OBJECT_ID('PdtDct') IS NOT NULL
    PRINT '<<< CREATED TABLE PdtDct >>>'
ELSE
    PRINT '<<< FAILED CREATING TABLE PdtDct >>>'
go

/* 
 * TABLE: PdtDsp 
 */

CREATE TABLE PdtDsp(
    PdtDspID    int                 IDENTITY(1,1),
    Dsp         nvarchar(400)       NOT NULL,
    rowguid     uniqueidentifier    ROWGUIDCOL NOT NULL,
    MdfDte      datetime            NOT NULL,
    CONSTRAINT PK_ProductDescription_ProductDescriptionID PRIMARY KEY CLUSTERED (PdtDspID)
)
go



IF OBJECT_ID('PdtDsp') IS NOT NULL
    PRINT '<<< CREATED TABLE PdtDsp >>>'
ELSE
    PRINT '<<< FAILED CREATING TABLE PdtDsp >>>'
go

/* 
 * TABLE: PdtInv 
 */

CREATE TABLE PdtInv(
    PdtID       int                 NOT NULL,
    LocID       smallint            NOT NULL,
    Shelf       nvarchar(10)        NOT NULL,
    Bin         tinyint             NOT NULL,
    Quantity    smallint            NOT NULL,
    rowguid     uniqueidentifier    ROWGUIDCOL NOT NULL,
    MdfDte      datetime            NOT NULL,
    CONSTRAINT PK_ProductInventory_ProductID_LocationID PRIMARY KEY CLUSTERED (PdtID, LocID)
)
go



IF OBJECT_ID('PdtInv') IS NOT NULL
    PRINT '<<< CREATED TABLE PdtInv >>>'
ELSE
    PRINT '<<< FAILED CREATING TABLE PdtInv >>>'
go

/* 
 * TABLE: PdtLstPrcHst 
 */

CREATE TABLE PdtLstPrcHst(
    PdtID     int         NOT NULL,
    SttDte    datetime    NOT NULL,
    EndDte    datetime    NULL,
    LstPrc    money       NOT NULL,
    MdfDte    datetime    NOT NULL,
    CONSTRAINT PK_ProductLastPriceHistory_ProductID_StartDate PRIMARY KEY CLUSTERED (PdtID, SttDte)
)
go



IF OBJECT_ID('PdtLstPrcHst') IS NOT NULL
    PRINT '<<< CREATED TABLE PdtLstPrcHst >>>'
ELSE
    PRINT '<<< FAILED CREATING TABLE PdtLstPrcHst >>>'
go

/* 
 * TABLE: PdtModelIll 
 */

CREATE TABLE PdtModelIll(
    PdtModelID    int         NOT NULL,
    IllID         int         NOT NULL,
    MdfDte        datetime    NOT NULL,
    CONSTRAINT PK_ProductModelIllustration_ProductModelID_IllustrationID PRIMARY KEY CLUSTERED (PdtModelID, IllID)
)
go



IF OBJECT_ID('PdtModelIll') IS NOT NULL
    PRINT '<<< CREATED TABLE PdtModelIll >>>'
ELSE
    PRINT '<<< FAILED CREATING TABLE PdtModelIll >>>'
go

/* 
 * TABLE: PdtModelPdtDspCtr 
 */

CREATE TABLE PdtModelPdtDspCtr(
    PdtModelID    int         NOT NULL,
    PdtDspID      int         NOT NULL,
    CtrID         nchar(6)    NOT NULL,
    MdfDte        datetime    NOT NULL,
    CONSTRAINT PK_ProductModelProductDescriptionCulture_ProductModelID_ProductDe PRIMARY KEY CLUSTERED (PdtModelID, PdtDspID, CtrID)
)
go



IF OBJECT_ID('PdtModelPdtDspCtr') IS NOT NULL
    PRINT '<<< CREATED TABLE PdtModelPdtDspCtr >>>'
ELSE
    PRINT '<<< FAILED CREATING TABLE PdtModelPdtDspCtr >>>'
go

/* 
 * TABLE: PdtPht 
 */

CREATE TABLE PdtPht(
    PdtPhtID               int               IDENTITY(1,1),
    ThumbNailPht           varbinary(max)    NULL,
    ThumbnailPhtFileNme    nvarchar(50)      NULL,
    LargePht               varbinary(max)    NULL,
    LargePhtFileNme        nvarchar(50)      NULL,
    MdfDte                 datetime          NOT NULL,
    CONSTRAINT PK_ProductPhoto_ProductPhotoID PRIMARY KEY CLUSTERED (PdtPhtID)
)
go



IF OBJECT_ID('PdtPht') IS NOT NULL
    PRINT '<<< CREATED TABLE PdtPht >>>'
ELSE
    PRINT '<<< FAILED CREATING TABLE PdtPht >>>'
go

/* 
 * TABLE: PdtRvw 
 */

CREATE TABLE PdtRvw(
    PdtRvwID       int               IDENTITY(1,1),
    PdtID          int               NOT NULL,
    ReviewerNme    Name              NOT NULL,
    RvwDte         datetime          NOT NULL,
    EmlAdr         nvarchar(50)      NOT NULL,
    Rating         int               NOT NULL,
    Comments       nvarchar(3850)    NULL,
    MdfDte         datetime          NOT NULL,
    CONSTRAINT PK_ProductReview_ProductReviewID PRIMARY KEY CLUSTERED (PdtRvwID)
)
go



IF OBJECT_ID('PdtRvw') IS NOT NULL
    PRINT '<<< CREATED TABLE PdtRvw >>>'
ELSE
    PRINT '<<< FAILED CREATING TABLE PdtRvw >>>'
go

/* 
 * TABLE: PdtScy 
 */

CREATE TABLE PdtScy(
    PdtScyID    int                 IDENTITY(1,1),
    PdtCtyID    int                 NOT NULL,
    Nme         Name                NOT NULL,
    rowguid     uniqueidentifier    ROWGUIDCOL NOT NULL,
    MdfDte      datetime            NOT NULL,
    CONSTRAINT PK_ProductSubcategory_ProductSubcategoryID PRIMARY KEY CLUSTERED (PdtScyID)
)
go



IF OBJECT_ID('PdtScy') IS NOT NULL
    PRINT '<<< CREATED TABLE PdtScy >>>'
ELSE
    PRINT '<<< FAILED CREATING TABLE PdtScy >>>'
go

/* 
 * TABLE: PdtVdr 
 */

CREATE TABLE PdtVdr(
    PdtID              int         NOT NULL,
    VdrID              int         NOT NULL,
    AverageLeadTime    int         NOT NULL,
    StdPrc             money       NOT NULL,
    LstReceiptCst      money       NULL,
    LstReceiptDte      datetime    NULL,
    MinOrdQty          int         NOT NULL,
    MaxOrdQty          int         NOT NULL,
    OnOrdQty           int         NULL,
    UitMsrCde          nchar(3)    NOT NULL,
    MdfDte             datetime    NOT NULL,
    CONSTRAINT PK_ProductVendor_ProductID_VendorID PRIMARY KEY CLUSTERED (PdtID, VdrID)
)
go



IF OBJECT_ID('PdtVdr') IS NOT NULL
    PRINT '<<< CREATED TABLE PdtVdr >>>'
ELSE
    PRINT '<<< FAILED CREATING TABLE PdtVdr >>>'
go

/* 
 * TABLE: PurOrdHdr 
 */

CREATE TABLE PurOrdHdr(
    PurOrdID       int         IDENTITY(1,1),
    RevisionNmb    tinyint     NOT NULL,
    Status         tinyint     NOT NULL,
    EmpID          int         NOT NULL,
    VdrID          int         NOT NULL,
    ShipMtdID      int         NOT NULL,
    OrdDte         datetime    NOT NULL,
    ShipDte        datetime    NULL,
    SubTotal       money       NOT NULL,
    TaxAmt         money       NOT NULL,
    Freight        money       NOT NULL,
    TotalDue       AS          (isnull(([SubTotal]+[TaxAmt])+[Freight],(0))),
    MdfDte         datetime    NOT NULL,
    CONSTRAINT PK_PurchaseOrderHeader_PurchaseOrderID PRIMARY KEY CLUSTERED (PurOrdID)
)
go



IF OBJECT_ID('PurOrdHdr') IS NOT NULL
    PRINT '<<< CREATED TABLE PurOrdHdr >>>'
ELSE
    PRINT '<<< FAILED CREATING TABLE PurOrdHdr >>>'
go

/* 
 * TABLE: ScrRsn 
 */

CREATE TABLE ScrRsn(
    ScrRsnID    smallint    IDENTITY(1,1),
    Nme         Name        NOT NULL,
    MdfDte      datetime    NOT NULL,
    CONSTRAINT PK_ScrapReason_ScrapReasonID PRIMARY KEY CLUSTERED (ScrRsnID)
)
go



IF OBJECT_ID('ScrRsn') IS NOT NULL
    PRINT '<<< CREATED TABLE ScrRsn >>>'
ELSE
    PRINT '<<< FAILED CREATING TABLE ScrRsn >>>'
go

/* 
 * TABLE: Sft 
 */

CREATE TABLE Sft(
    SftID      tinyint     IDENTITY(1,1),
    Nme        Name        NOT NULL,
    SttTime    datetime    NOT NULL,
    EndTime    datetime    NOT NULL,
    MdfDte     datetime    NOT NULL,
    CONSTRAINT PK_Shift_SafetyID PRIMARY KEY CLUSTERED (SftID)
)
go



IF OBJECT_ID('Sft') IS NOT NULL
    PRINT '<<< CREATED TABLE Sft >>>'
ELSE
    PRINT '<<< FAILED CREATING TABLE Sft >>>'
go

/* 
 * TABLE: ShipMtd 
 */

CREATE TABLE ShipMtd(
    ShipMtdID    int                 IDENTITY(1,1),
    Nme          Name                NOT NULL,
    ShipBase     money               NOT NULL,
    ShipRat      money               NOT NULL,
    rowguid      uniqueidentifier    ROWGUIDCOL NOT NULL,
    MdfDte       datetime            NOT NULL,
    CONSTRAINT PK_ShipMethod_ShipMethodID PRIMARY KEY CLUSTERED (ShipMtdID)
)
go



IF OBJECT_ID('ShipMtd') IS NOT NULL
    PRINT '<<< CREATED TABLE ShipMtd >>>'
ELSE
    PRINT '<<< FAILED CREATING TABLE ShipMtd >>>'
go

/* 
 * TABLE: ShpCrtItm 
 */

CREATE TABLE ShpCrtItm(
    ShpCrtItmID    int             IDENTITY(1,1),
    ShpCrtID       nvarchar(50)    NOT NULL,
    Quantity       int             NOT NULL,
    PdtID          int             NOT NULL,
    DteCreated     datetime        NOT NULL,
    MdfDte         datetime        NOT NULL,
    CONSTRAINT PK_ShoppingCartItem_ShoppingCartItemID PRIMARY KEY CLUSTERED (ShpCrtItmID)
)
go



IF OBJECT_ID('ShpCrtItm') IS NOT NULL
    PRINT '<<< CREATED TABLE ShpCrtItm >>>'
ELSE
    PRINT '<<< FAILED CREATING TABLE ShpCrtItm >>>'
go

/* 
 * TABLE: SlsOrdHdrSlsRsn 
 */

CREATE TABLE SlsOrdHdrSlsRsn(
    SlsOrdID    int         NOT NULL,
    SlsRsnID    int         NOT NULL,
    MdfDte      datetime    NOT NULL,
    CONSTRAINT PK_SalesOrderHeaderSalesReason_SalesOrderID_SalesReasonID PRIMARY KEY CLUSTERED (SlsOrdID, SlsRsnID)
)
go



IF OBJECT_ID('SlsOrdHdrSlsRsn') IS NOT NULL
    PRINT '<<< CREATED TABLE SlsOrdHdrSlsRsn >>>'
ELSE
    PRINT '<<< FAILED CREATING TABLE SlsOrdHdrSlsRsn >>>'
go

/* 
 * TABLE: SlsPsn 
 */

CREATE TABLE SlsPsn(
    EmpID            int                 NOT NULL,
    TtyID            int                 NULL,
    SlsQta           money               NULL,
    Bonus            money               NOT NULL,
    CommissionPct    smallmoney          NOT NULL,
    SlsYTD           money               NOT NULL,
    SlsLstYear       money               NOT NULL,
    rowguid          uniqueidentifier    ROWGUIDCOL NOT NULL,
    MdfDte           datetime            NOT NULL,
    CONSTRAINT PK_SalesPerson_SalesPersonID PRIMARY KEY CLUSTERED (EmpID)
)
go



IF OBJECT_ID('SlsPsn') IS NOT NULL
    PRINT '<<< CREATED TABLE SlsPsn >>>'
ELSE
    PRINT '<<< FAILED CREATING TABLE SlsPsn >>>'
go

/* 
 * TABLE: SlsPsnQtaHst 
 */

CREATE TABLE SlsPsnQtaHst(
    EmpID      int                 NOT NULL,
    QtaDte     datetime            NOT NULL,
    SlsQta     money               NOT NULL,
    rowguid    uniqueidentifier    ROWGUIDCOL NOT NULL,
    MdfDte     datetime            NOT NULL,
    CONSTRAINT PK_SalesPersonQuotaHistory_SalesPersonID_QuotaDate PRIMARY KEY CLUSTERED (EmpID, QtaDte)
)
go



IF OBJECT_ID('SlsPsnQtaHst') IS NOT NULL
    PRINT '<<< CREATED TABLE SlsPsnQtaHst >>>'
ELSE
    PRINT '<<< FAILED CREATING TABLE SlsPsnQtaHst >>>'
go

/* 
 * TABLE: SlsRsn 
 */

CREATE TABLE SlsRsn(
    SlsRsnID    int         IDENTITY(1,1),
    Nme         Name        NOT NULL,
    RsnTyp      Name        NOT NULL,
    MdfDte      datetime    NOT NULL,
    CONSTRAINT PK_SalesReason_SalesReasonID PRIMARY KEY CLUSTERED (SlsRsnID)
)
go



IF OBJECT_ID('SlsRsn') IS NOT NULL
    PRINT '<<< CREATED TABLE SlsRsn >>>'
ELSE
    PRINT '<<< FAILED CREATING TABLE SlsRsn >>>'
go

/* 
 * TABLE: SlsTaxRat 
 */

CREATE TABLE SlsTaxRat(
    SlsTaxRatID    int                 IDENTITY(1,1),
    StePovID       int                 NOT NULL,
    TaxTyp         tinyint             NOT NULL,
    TaxRat         smallmoney          NOT NULL,
    Nme            Name                NOT NULL,
    rowguid        uniqueidentifier    ROWGUIDCOL NOT NULL,
    MdfDte         datetime            NOT NULL,
    CONSTRAINT PK_SalesTaxRate_SalesTaxRateID PRIMARY KEY CLUSTERED (SlsTaxRatID)
)
go



IF OBJECT_ID('SlsTaxRat') IS NOT NULL
    PRINT '<<< CREATED TABLE SlsTaxRat >>>'
ELSE
    PRINT '<<< FAILED CREATING TABLE SlsTaxRat >>>'
go

/* 
 * TABLE: SlsTty 
 */

CREATE TABLE SlsTty(
    TtyID         int                 IDENTITY(1,1),
    Nme           Name                NOT NULL,
    CtyRgnCde     nvarchar(3)         NOT NULL,
    Grp           nvarchar(50)        NOT NULL,
    SlsYTD        money               NOT NULL,
    SlsLstYear    money               NOT NULL,
    CstYTD        money               NOT NULL,
    CstLstYear    money               NOT NULL,
    rowguid       uniqueidentifier    ROWGUIDCOL NOT NULL,
    MdfDte        datetime            NOT NULL,
    CONSTRAINT PK_SalesTerritory_TerritoryID PRIMARY KEY CLUSTERED (TtyID)
)
go



IF OBJECT_ID('SlsTty') IS NOT NULL
    PRINT '<<< CREATED TABLE SlsTty >>>'
ELSE
    PRINT '<<< FAILED CREATING TABLE SlsTty >>>'
go

/* 
 * TABLE: SlsTtyHst 
 */

CREATE TABLE SlsTtyHst(
    EmpID      int                 NOT NULL,
    TtyID      int                 NOT NULL,
    SttDte     datetime            NOT NULL,
    EndDte     datetime            NULL,
    rowguid    uniqueidentifier    ROWGUIDCOL NOT NULL,
    MdfDte     datetime            NOT NULL,
    CONSTRAINT PK_SalesTerritoryHistory_SalesPersonID_StartDate_TerritoryID PRIMARY KEY CLUSTERED (EmpID, SttDte, TtyID)
)
go



IF OBJECT_ID('SlsTtyHst') IS NOT NULL
    PRINT '<<< CREATED TABLE SlsTtyHst >>>'
ELSE
    PRINT '<<< FAILED CREATING TABLE SlsTtyHst >>>'
go

/* 
 * TABLE: SplOffer 
 */

CREATE TABLE SplOffer(
    SplOfferID     int                 IDENTITY(1,1),
    Dsp            nvarchar(255)       NOT NULL,
    DiscountPct    smallmoney          NOT NULL,
    Typ            nvarchar(50)        NOT NULL,
    Cty            nvarchar(50)        NOT NULL,
    SttDte         datetime            NOT NULL,
    EndDte         datetime            NOT NULL,
    MinQty         int                 NOT NULL,
    MaxQty         int                 NULL,
    rowguid        uniqueidentifier    ROWGUIDCOL NOT NULL,
    MdfDte         datetime            NOT NULL,
    CONSTRAINT PK_SpecialOffer_SpecialOfferID PRIMARY KEY CLUSTERED (SplOfferID)
)
go



IF OBJECT_ID('SplOffer') IS NOT NULL
    PRINT '<<< CREATED TABLE SplOffer >>>'
ELSE
    PRINT '<<< FAILED CREATING TABLE SplOffer >>>'
go

/* 
 * TABLE: SplOfferPdt 
 */

CREATE TABLE SplOfferPdt(
    SplOfferID    int                 NOT NULL,
    PdtID         int                 NOT NULL,
    rowguid       uniqueidentifier    ROWGUIDCOL NOT NULL,
    MdfDte        datetime            NOT NULL,
    CONSTRAINT PK_SpecialOfferProduct_SpecialOfferID_ProductID PRIMARY KEY CLUSTERED (SplOfferID, PdtID)
)
go



IF OBJECT_ID('SplOfferPdt') IS NOT NULL
    PRINT '<<< CREATED TABLE SplOfferPdt >>>'
ELSE
    PRINT '<<< FAILED CREATING TABLE SplOfferPdt >>>'
go

/* 
 * TABLE: StePov 
 */

CREATE TABLE StePov(
    StePovID            int                 IDENTITY(1,1),
    StePovCde           nchar(3)            NOT NULL,
    CtyRgnCde           nvarchar(3)         NOT NULL,
    IsOnlyStePovFlag    Flag                NOT NULL,
    Nme                 Name                NOT NULL,
    TtyID               int                 NOT NULL,
    rowguid             uniqueidentifier    ROWGUIDCOL NOT NULL,
    MdfDte              datetime            NOT NULL,
    CONSTRAINT PK_StateProvince_StateProvinceID PRIMARY KEY CLUSTERED (StePovID)
)
go



IF OBJECT_ID('StePov') IS NOT NULL
    PRINT '<<< CREATED TABLE StePov >>>'
ELSE
    PRINT '<<< FAILED CREATING TABLE StePov >>>'
go

/* 
 * TABLE: StrCct 
 */

CREATE TABLE StrCct(
    CmrID       int                 NOT NULL,
    CctID       int                 NOT NULL,
    CctTypID    int                 NOT NULL,
    rowguid     uniqueidentifier    ROWGUIDCOL NOT NULL,
    MdfDte      datetime            NOT NULL,
    CONSTRAINT PK_StoreContact_CustomerID_ContactID PRIMARY KEY CLUSTERED (CmrID, CctID)
)
go



IF OBJECT_ID('StrCct') IS NOT NULL
    PRINT '<<< CREATED TABLE StrCct >>>'
ELSE
    PRINT '<<< FAILED CREATING TABLE StrCct >>>'
go

/* 
 * TABLE: TrnHst 
 */

CREATE TABLE TrnHst(
    TrnID                 int         IDENTITY(100000,1),
    PdtID                 int         NOT NULL,
    ReferenceOrdID        int         NOT NULL,
    ReferenceOrdLineID    int         NOT NULL,
    TrnDte                datetime    NOT NULL,
    TrnTyp                nchar(1)    NOT NULL,
    Quantity              int         NOT NULL,
    ActualCst             money       NOT NULL,
    MdfDte                datetime    NOT NULL,
    CONSTRAINT PK_TransactionHistory_TransactionID PRIMARY KEY CLUSTERED (TrnID)
)
go



IF OBJECT_ID('TrnHst') IS NOT NULL
    PRINT '<<< CREATED TABLE TrnHst >>>'
ELSE
    PRINT '<<< FAILED CREATING TABLE TrnHst >>>'
go

/* 
 * TABLE: TrnHstArv 
 */

CREATE TABLE TrnHstArv(
    TrnID                 int         NOT NULL,
    PdtID                 int         NOT NULL,
    ReferenceOrdID        int         NOT NULL,
    ReferenceOrdLineID    int         NOT NULL,
    TrnDte                datetime    NOT NULL,
    TrnTyp                nchar(1)    NOT NULL,
    Quantity              int         NOT NULL,
    ActualCst             money       NOT NULL,
    MdfDte                datetime    NOT NULL,
    CONSTRAINT PK_TransactionHistoryArchive_TransactionID PRIMARY KEY CLUSTERED (TrnID)
)
go



IF OBJECT_ID('TrnHstArv') IS NOT NULL
    PRINT '<<< CREATED TABLE TrnHstArv >>>'
ELSE
    PRINT '<<< FAILED CREATING TABLE TrnHstArv >>>'
go

/* 
 * TABLE: UitMsr 
 */

CREATE TABLE UitMsr(
    UitMsrCde    nchar(3)    NOT NULL,
    Nme          Name        NOT NULL,
    MdfDte       datetime    NOT NULL,
    CONSTRAINT PK_UnitMeasure_UnitMeasureCode PRIMARY KEY CLUSTERED (UitMsrCde)
)
go



IF OBJECT_ID('UitMsr') IS NOT NULL
    PRINT '<<< CREATED TABLE UitMsr >>>'
ELSE
    PRINT '<<< FAILED CREATING TABLE UitMsr >>>'
go

/* 
 * TABLE: Vdr 
 */

CREATE TABLE Vdr(
    VdrID                      int               IDENTITY(1,1),
    ActNmb                     AccountNumber     NOT NULL,
    Nme                        Name              NOT NULL,
    CrtRating                  tinyint           NOT NULL,
    PreferredVdrStatus         Flag              NOT NULL,
    ActiveFlag                 Flag              NOT NULL,
    PurchasingWebServiceURL    nvarchar(1024)    NULL,
    MdfDte                     datetime          NOT NULL,
    CONSTRAINT PK_Vendor_VendorID PRIMARY KEY CLUSTERED (VdrID)
)
go



IF OBJECT_ID('Vdr') IS NOT NULL
    PRINT '<<< CREATED TABLE Vdr >>>'
ELSE
    PRINT '<<< FAILED CREATING TABLE Vdr >>>'
go

/* 
 * TABLE: VdrAdr 
 */

CREATE TABLE VdrAdr(
    VdrID       int         NOT NULL,
    AdrID       int         NOT NULL,
    AdrTypID    int         NOT NULL,
    MdfDte      datetime    NOT NULL,
    CONSTRAINT PK_VendorAddress_VendorID_AddressID PRIMARY KEY CLUSTERED (VdrID, AdrID)
)
go



IF OBJECT_ID('VdrAdr') IS NOT NULL
    PRINT '<<< CREATED TABLE VdrAdr >>>'
ELSE
    PRINT '<<< FAILED CREATING TABLE VdrAdr >>>'
go

/* 
 * TABLE: VdrCct 
 */

CREATE TABLE VdrCct(
    VdrID       int         NOT NULL,
    CctID       int         NOT NULL,
    CctTypID    int         NOT NULL,
    MdfDte      datetime    NOT NULL,
    CONSTRAINT PK_VendorContact_VendorID_ContactID PRIMARY KEY CLUSTERED (VdrID, CctID)
)
go



IF OBJECT_ID('VdrCct') IS NOT NULL
    PRINT '<<< CREATED TABLE VdrCct >>>'
ELSE
    PRINT '<<< FAILED CREATING TABLE VdrCct >>>'
go

/* 
 * TABLE: WrkOrdRtg 
 */

CREATE TABLE WrkOrdRtg(
    WrkOrdID             int              NOT NULL,
    PdtID                int              NOT NULL,
    OperationSequence    smallint         NOT NULL,
    LocID                smallint         NOT NULL,
    ScheduledSttDte      datetime         NOT NULL,
    ScheduledEndDte      datetime         NOT NULL,
    ActualSttDte         datetime         NULL,
    ActualEndDte         datetime         NULL,
    ActualResourceHrs    decimal(9, 4)    NULL,
    PlannedCst           money            NOT NULL,
    ActualCst            money            NULL,
    MdfDte               datetime         NOT NULL,
    CONSTRAINT PK_WorkOrderRouting_WorkOrderID_ProductID_OperationSequence PRIMARY KEY CLUSTERED (WrkOrdID, PdtID, OperationSequence)
)
go



IF OBJECT_ID('WrkOrdRtg') IS NOT NULL
    PRINT '<<< CREATED TABLE WrkOrdRtg >>>'
ELSE
    PRINT '<<< FAILED CREATING TABLE WrkOrdRtg >>>'
go

/* 
 * TABLE: Adr 
 */

ALTER TABLE Adr ADD CONSTRAINT FK__Adr__StateProvinceID__7F6BDA51 
    FOREIGN KEY (StePovID)
    REFERENCES StePov(StePovID)
go


/* 
 * TABLE: BllOfMls 
 */

ALTER TABLE BllOfMls ADD CONSTRAINT FK__BillOfMls__ProductID__015422C3 
    FOREIGN KEY (PdtID)
    REFERENCES Pdt(PdtID)
go

ALTER TABLE BllOfMls ADD CONSTRAINT FK__BillOfMls__ProductID___005FFE8A 
    FOREIGN KEY (PdtID_1)
    REFERENCES Pdt(PdtID)
go

ALTER TABLE BllOfMls ADD CONSTRAINT FK__BillOfMls__UnitMsr__024846FC 
    FOREIGN KEY (UitMsrCde)
    REFERENCES UitMsr(UitMsrCde)
go


/* 
 * TABLE: CctCrtCrd 
 */

ALTER TABLE CctCrtCrd ADD CONSTRAINT FK__ContactCartCrd__CartCr__04308F6E 
    FOREIGN KEY (CrtCrdID)
    REFERENCES CrtCrd(CrtCrdID)
go

ALTER TABLE CctCrtCrd ADD CONSTRAINT FK__ContactCartCrd__ContactID__44160A59 
    FOREIGN KEY (CctID)
    REFERENCES Cct(CctID)
go


/* 
 * TABLE: Cmr 
 */

ALTER TABLE Cmr ADD CONSTRAINT FK__Cmr__TerritoryID__0524B3A7 
    FOREIGN KEY (TtyID)
    REFERENCES SlsTty(TtyID)
go


/* 
 * TABLE: CmrAdr 
 */

ALTER TABLE CmrAdr ADD CONSTRAINT FK__CustomerAdr__AddressID__0618D7E0 
    FOREIGN KEY (AdrID)
    REFERENCES Adr(AdrID)
go

ALTER TABLE CmrAdr ADD CONSTRAINT FK__CustomerAdr__AddressTypeID__070CFC19 
    FOREIGN KEY (AdrTypID)
    REFERENCES AdrTyp(AdrTypID)
go

ALTER TABLE CmrAdr ADD CONSTRAINT FK__CustomerAdr__CustomerID__08012052 
    FOREIGN KEY (CmrID)
    REFERENCES Cmr(CmrID)
go


/* 
 * TABLE: CryRat 
 */

ALTER TABLE CryRat ADD CONSTRAINT FK__CurrencyRat__CurrencyCde_1__09E968C4 
    FOREIGN KEY (CryCde_1)
    REFERENCES Cry(CryCde)
go

ALTER TABLE CryRat ADD CONSTRAINT FK__CurrencyRat__CurrencyCde__08F5448B 
    FOREIGN KEY (CryCde)
    REFERENCES Cry(CryCde)
go


/* 
 * TABLE: CtyRgnCry 
 */

ALTER TABLE CtyRgnCry ADD CONSTRAINT FK__CategoryRegionCry__CategoryRg__0ADD8CFD 
    FOREIGN KEY (CtyRgnCde)
    REFERENCES CtyRgn(CtyRgnCde)
go

ALTER TABLE CtyRgnCry ADD CONSTRAINT FK__CategoryRegionCry__CurrencyCd__0BD1B136 
    FOREIGN KEY (CryCde)
    REFERENCES Cry(CryCde)
go


/* 
 * TABLE: Emp 
 */

ALTER TABLE Emp ADD CONSTRAINT FK__Emp__ContactID__450A2E92 
    FOREIGN KEY (CctID)
    REFERENCES Cct(CctID)
go

ALTER TABLE Emp ADD CONSTRAINT FK__Emp__EmployeeID_1__0DB9F9A8 
    FOREIGN KEY (EmpID_1)
    REFERENCES Emp(EmpID)
go


/* 
 * TABLE: EmpAdr 
 */

ALTER TABLE EmpAdr ADD CONSTRAINT FK__EmployeeAdr__AddressID__0EAE1DE1 
    FOREIGN KEY (AdrID)
    REFERENCES Adr(AdrID)
go

ALTER TABLE EmpAdr ADD CONSTRAINT FK__EmployeeAdr__EmployeeID__0FA2421A 
    FOREIGN KEY (EmpID)
    REFERENCES Emp(EmpID)
go


/* 
 * TABLE: EmpDepHst 
 */

ALTER TABLE EmpDepHst ADD CONSTRAINT FK__EmployeeDepartmentHst__DepartmentID__10966653 
    FOREIGN KEY (DepID)
    REFERENCES Dep(DepID)
go

ALTER TABLE EmpDepHst ADD CONSTRAINT FK__EmployeeDepartmentHst__EmployeeID__118A8A8C 
    FOREIGN KEY (EmpID)
    REFERENCES Emp(EmpID)
go

ALTER TABLE EmpDepHst ADD CONSTRAINT FK__EmployeeDepartmentHst__SafetyID__127EAEC5 
    FOREIGN KEY (SftID)
    REFERENCES Sft(SftID)
go


/* 
 * TABLE: EmpPayHst 
 */

ALTER TABLE EmpPayHst ADD CONSTRAINT FK__EmployeePayHst__EmployeeID__1372D2FE 
    FOREIGN KEY (EmpID)
    REFERENCES Emp(EmpID)
go


/* 
 * TABLE: Pdt 
 */

ALTER TABLE Pdt ADD CONSTRAINT FK__Pdt__ProductSubcategoryID__155B1B70 
    FOREIGN KEY (PdtScyID)
    REFERENCES PdtScy(PdtScyID)
go

ALTER TABLE Pdt ADD CONSTRAINT FK__Pdt__UnitMeasureCde_1__174363E2 
    FOREIGN KEY (UitMsrCde_1)
    REFERENCES UitMsr(UitMsrCde)
go

ALTER TABLE Pdt ADD CONSTRAINT FK__Pdt__UnitMeasureCde__164F3FA9 
    FOREIGN KEY (UitMsrCde)
    REFERENCES UitMsr(UitMsrCde)
go


/* 
 * TABLE: Pdt_02182013171245000 
 */

ALTER TABLE Pdt_02182013171245000 ADD CONSTRAINT FK__Pdt__P_02182013171245002 
    FOREIGN KEY (PdtScyID)
    REFERENCES PdtScy(PdtScyID)
go

ALTER TABLE Pdt_02182013171245000 ADD CONSTRAINT FK__Pdt__U_02182013171245003 
    FOREIGN KEY (UitMsrCde)
    REFERENCES UitMsr(UitMsrCde)
go

ALTER TABLE Pdt_02182013171245000 ADD CONSTRAINT FK__Pdt__U_02182013171245004 
    FOREIGN KEY (UitMsrCde_1)
    REFERENCES UitMsr(UitMsrCde)
go


/* 
 * TABLE: PdtCstHst 
 */

ALTER TABLE PdtCstHst ADD CONSTRAINT FK__ProductCostHst__ProductID__1837881B 
    FOREIGN KEY (PdtID)
    REFERENCES Pdt(PdtID)
go


/* 
 * TABLE: PdtDct 
 */

ALTER TABLE PdtDct ADD CONSTRAINT FK__ProductDct__DocumentID__192BAC54 
    FOREIGN KEY (DctID)
    REFERENCES Dct(DctID)
go

ALTER TABLE PdtDct ADD CONSTRAINT FK__ProductDct__ProductID__1A1FD08D 
    FOREIGN KEY (PdtID)
    REFERENCES Pdt(PdtID)
go


/* 
 * TABLE: PdtInv 
 */

ALTER TABLE PdtInv ADD CONSTRAINT FK__ProductInv__LocationID__1B13F4C6 
    FOREIGN KEY (LocID)
    REFERENCES Loc(LocID)
go

ALTER TABLE PdtInv ADD CONSTRAINT FK__ProductInv__ProductID__1C0818FF 
    FOREIGN KEY (PdtID)
    REFERENCES Pdt(PdtID)
go


/* 
 * TABLE: PdtLstPrcHst 
 */

ALTER TABLE PdtLstPrcHst ADD CONSTRAINT FK__ProductLastPrc__ProductID__1CFC3D38 
    FOREIGN KEY (PdtID)
    REFERENCES Pdt(PdtID)
go


/* 
 * TABLE: PdtModelIll 
 */

ALTER TABLE PdtModelIll ADD CONSTRAINT FK__ProductModelI__IllustrationID__1DF06171 
    FOREIGN KEY (IllID)
    REFERENCES Ill(IllID)
go


/* 
 * TABLE: PdtModelPdtDspCtr 
 */

ALTER TABLE PdtModelPdtDspCtr ADD CONSTRAINT FK__ProductModelP__CultureID__1FD8A9E3 
    FOREIGN KEY (CtrID)
    REFERENCES Ctr(CtrID)
go

ALTER TABLE PdtModelPdtDspCtr ADD CONSTRAINT FK__ProductModelP__ProductDs__20CCCE1C 
    FOREIGN KEY (PdtDspID)
    REFERENCES PdtDsp(PdtDspID)
go


/* 
 * TABLE: PdtRvw 
 */

ALTER TABLE PdtRvw ADD CONSTRAINT FK__ProductRvw__ProductID__22B5168E 
    FOREIGN KEY (PdtID)
    REFERENCES Pdt(PdtID)
go


/* 
 * TABLE: PdtScy 
 */

ALTER TABLE PdtScy ADD CONSTRAINT FK__ProductScy__ProductCategoryID__23A93AC7 
    FOREIGN KEY (PdtCtyID)
    REFERENCES PdtCty(PdtCtyID)
go


/* 
 * TABLE: PdtVdr 
 */

ALTER TABLE PdtVdr ADD CONSTRAINT FK__ProductVdr__ProductID__249D5F00 
    FOREIGN KEY (PdtID)
    REFERENCES Pdt(PdtID)
go

ALTER TABLE PdtVdr ADD CONSTRAINT FK__ProductVdr__UnitMeasureCd__25918339 
    FOREIGN KEY (UitMsrCde)
    REFERENCES UitMsr(UitMsrCde)
go

ALTER TABLE PdtVdr ADD CONSTRAINT FK__ProductVdr__VendorID__2685A772 
    FOREIGN KEY (VdrID)
    REFERENCES Vdr(VdrID)
go


/* 
 * TABLE: PurOrdHdr 
 */

ALTER TABLE PurOrdHdr ADD CONSTRAINT FK__PurchaseOrderHdr__EmployeeID__2779CBAB 
    FOREIGN KEY (EmpID)
    REFERENCES Emp(EmpID)
go

ALTER TABLE PurOrdHdr ADD CONSTRAINT FK__PurchaseOrderHdr__ShipM__286DEFE4 
    FOREIGN KEY (ShipMtdID)
    REFERENCES ShipMtd(ShipMtdID)
go

ALTER TABLE PurOrdHdr ADD CONSTRAINT FK__PurchaseOrderHdr__VendorID__2962141D 
    FOREIGN KEY (VdrID)
    REFERENCES Vdr(VdrID)
go


/* 
 * TABLE: ShpCrtItm 
 */

ALTER TABLE ShpCrtItm ADD CONSTRAINT FK__ShoppingCartItm__ProductID__2A563856 
    FOREIGN KEY (PdtID)
    REFERENCES Pdt(PdtID)
go


/* 
 * TABLE: SlsOrdHdrSlsRsn 
 */

ALTER TABLE SlsOrdHdrSlsRsn ADD CONSTRAINT FK__SalesOrderHdr__SalesRs__2C3E80C8 
    FOREIGN KEY (SlsRsnID)
    REFERENCES SlsRsn(SlsRsnID)
go


/* 
 * TABLE: SlsPsn 
 */

ALTER TABLE SlsPsn ADD CONSTRAINT FK__SalesPsn__EmployeeID__2D32A501 
    FOREIGN KEY (EmpID)
    REFERENCES Emp(EmpID)
go

ALTER TABLE SlsPsn ADD CONSTRAINT FK__SalesPsn__TerritoryID__2E26C93A 
    FOREIGN KEY (TtyID)
    REFERENCES SlsTty(TtyID)
go


/* 
 * TABLE: SlsPsnQtaHst 
 */

ALTER TABLE SlsPsnQtaHst ADD CONSTRAINT FK__SalesPersonQta__EmployeeID__2F1AED73 
    FOREIGN KEY (EmpID)
    REFERENCES SlsPsn(EmpID)
go


/* 
 * TABLE: SlsTaxRat 
 */

ALTER TABLE SlsTaxRat ADD CONSTRAINT FK__SalesTaxRat__StatePo__300F11AC 
    FOREIGN KEY (StePovID)
    REFERENCES StePov(StePovID)
go


/* 
 * TABLE: SlsTtyHst 
 */

ALTER TABLE SlsTtyHst ADD CONSTRAINT FK__SalesTerritoryHst__EmployeeID__310335E5 
    FOREIGN KEY (EmpID)
    REFERENCES SlsPsn(EmpID)
go

ALTER TABLE SlsTtyHst ADD CONSTRAINT FK__SalesTerritoryHst__TerritoryID__31F75A1E 
    FOREIGN KEY (TtyID)
    REFERENCES SlsTty(TtyID)
go


/* 
 * TABLE: SplOfferPdt 
 */

ALTER TABLE SplOfferPdt ADD CONSTRAINT FK__SpecialOfferP__ProductID__32EB7E57 
    FOREIGN KEY (PdtID)
    REFERENCES Pdt(PdtID)
go

ALTER TABLE SplOfferPdt ADD CONSTRAINT FK__SpecialOfferP__SpecialOf__33DFA290 
    FOREIGN KEY (SplOfferID)
    REFERENCES SplOffer(SplOfferID)
go


/* 
 * TABLE: StePov 
 */

ALTER TABLE StePov ADD CONSTRAINT FK__StatePov__CategoryRegionCd__34D3C6C9 
    FOREIGN KEY (CtyRgnCde)
    REFERENCES CtyRgn(CtyRgnCde)
go

ALTER TABLE StePov ADD CONSTRAINT FK__StatePov__TerritoryID__35C7EB02 
    FOREIGN KEY (TtyID)
    REFERENCES SlsTty(TtyID)
go


/* 
 * TABLE: StrCct 
 */

ALTER TABLE StrCct ADD CONSTRAINT FK__StoreCct__ContactID__45FE52CB 
    FOREIGN KEY (CctID)
    REFERENCES Cct(CctID)
go

ALTER TABLE StrCct ADD CONSTRAINT FK__StoreCct__ContactTypeID__36BC0F3B 
    FOREIGN KEY (CctTypID)
    REFERENCES CctTyp(CctTypID)
go


/* 
 * TABLE: TrnHst 
 */

ALTER TABLE TrnHst ADD CONSTRAINT FK__TransactionHst__ProductID__39987BE6 
    FOREIGN KEY (PdtID)
    REFERENCES Pdt(PdtID)
go


/* 
 * TABLE: VdrAdr 
 */

ALTER TABLE VdrAdr ADD CONSTRAINT FK__VendorAdr__AddressID__3A8CA01F 
    FOREIGN KEY (AdrID)
    REFERENCES Adr(AdrID)
go

ALTER TABLE VdrAdr ADD CONSTRAINT FK__VendorAdr__AddressTypeID__3B80C458 
    FOREIGN KEY (AdrTypID)
    REFERENCES AdrTyp(AdrTypID)
go

ALTER TABLE VdrAdr ADD CONSTRAINT FK__VendorAdr__VendorID__3C74E891 
    FOREIGN KEY (VdrID)
    REFERENCES Vdr(VdrID)
go


/* 
 * TABLE: VdrCct 
 */

ALTER TABLE VdrCct ADD CONSTRAINT FK__VendorCct__ContactID__46F27704 
    FOREIGN KEY (CctID)
    REFERENCES Cct(CctID)
go

ALTER TABLE VdrCct ADD CONSTRAINT FK__VendorCct__ContactTypeID__3D690CCA 
    FOREIGN KEY (CctTypID)
    REFERENCES CctTyp(CctTypID)
go

ALTER TABLE VdrCct ADD CONSTRAINT FK__VendorCct__VendorID__3F51553C 
    FOREIGN KEY (VdrID)
    REFERENCES Vdr(VdrID)
go


/* 
 * TABLE: WrkOrdRtg 
 */

ALTER TABLE WrkOrdRtg ADD CONSTRAINT FK__WorkOrderRtg__LocationID__40457975 
    FOREIGN KEY (LocID)
    REFERENCES Loc(LocID)
go


